# Classification Benchmarks

In this folder, you will find the different experiment files for classification
datasets.

## Image Classification

Note on VGG: We haven't figured out hyperparameters that would be acceptable
for VGG, even more so for Packed-Ensembles. Just adding groups to the standard
network impedes convergence for all tested hyperparameters.

### CIFAR-10

* ResNet
* WideResNet
* VGG

### CIFAR-100

* ResNet
* WideResNet
* VGG

### MNIST

* LeNet
* Bayesian LeNet

### Tiny-ImageNet200

* ResNet
